summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTarja Sundqvist <tarja.sundqvist@qt.io>2024-05-08 08:14:37 +0300
committerTarja Sundqvist <tarja.sundqvist@qt.io>2024-05-08 08:14:37 +0300
commit7315c48bcec88014e78165bbda54abfcd557e0af (patch)
tree147a504494629ed74f9df60bdcb6bd18f016d983
parent3f3f14d69a509c3e8027bfb5d7ffca9b4f3ef003 (diff)
parent2a610b9b42bef19fd2f825cdac2abaf2f434d4fd (diff)
Merge remote-tracking branch 'origin/tqtc/lts-5.15.14' into tqtc/lts-5.15-opensourcev5.15.14-lts-lgpl5.15
-rw-r--r--.qmake.conf2
-rw-r--r--examples/charts/audio/apple/Info.plist.in13
-rw-r--r--examples/charts/audio/audio.pro4
-rw-r--r--src/charts/layout/abstractchartlayout.cpp7
-rw-r--r--tests/auto/qbarseries/BLACKLIST2
5 files changed, 24 insertions, 4 deletions
diff --git a/.qmake.conf b/.qmake.conf
index 4a55f521..21085061 100644
--- a/.qmake.conf
+++ b/.qmake.conf
@@ -2,4 +2,4 @@ load(qt_build_config)
DEFINES += QT_NO_JAVA_STYLE_ITERATORS QT_NO_LINKED_LIST
-MODULE_VERSION = 5.15.13
+MODULE_VERSION = 5.15.14
diff --git a/examples/charts/audio/apple/Info.plist.in b/examples/charts/audio/apple/Info.plist.in
new file mode 100644
index 00000000..9e6cc252
--- /dev/null
+++ b/examples/charts/audio/apple/Info.plist.in
@@ -0,0 +1,13 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+ <key>CFBundleInfoDictionaryVersion</key>
+ <string>6.0</string>
+ <key>CFBundlePackageType</key>
+ <string>APPL</string>
+
+ <key>NSMicrophoneUsageDescription</key>
+ <string>Qt Charts Example</string>
+</dict>
+</plist>
diff --git a/examples/charts/audio/audio.pro b/examples/charts/audio/audio.pro
index c6df9be0..3d0e26e4 100644
--- a/examples/charts/audio/audio.pro
+++ b/examples/charts/audio/audio.pro
@@ -9,5 +9,9 @@ SOURCES += \
widget.cpp \
xyseriesiodevice.cpp
+darwin{
+ QMAKE_INFO_PLIST = apple/Info.plist.in
+}
+
target.path = $$[QT_INSTALL_EXAMPLES]/charts/audio
INSTALLS += target
diff --git a/tests/auto/qbarseries/BLACKLIST b/tests/auto/qbarseries/BLACKLIST
index c8b10b7d..7202437b 100644
--- a/tests/auto/qbarseries/BLACKLIST
+++ b/tests/auto/qbarseries/BLACKLIST
@@ -1,4 +1,4 @@
[mousehovered]
macos
# QTBUG-111293
-sles-15
+sles-15.4
diff --git a/src/charts/layout/abstractchartlayout.cpp b/src/charts/layout/abstractchartlayout.cpp
index c612d197..3d31dd07 100644
--- a/src/charts/layout/abstractchartlayout.cpp
+++ b/src/charts/layout/abstractchartlayout.cpp
@@ -54,8 +54,11 @@ void AbstractChartLayout::setGeometry(const QRectF &rect)
if (!rect.isValid())
return;
- // If the chart has a fixed geometry then don't update visually
- const bool updateLayout = (!m_presenter->isFixedGeometry() || m_presenter->geometry() == rect);
+ // If the chart has a fixed geometry then don't update visually, unless plotbackground is
+ // visible.
+ const bool updateLayout = (!m_presenter->isFixedGeometry()
+ || m_presenter->isPlotAreaBackgroundVisible()
+ || m_presenter->geometry() == rect);
if (m_presenter->chart()->isVisible()) {
QList<ChartAxisElement *> axes = m_presenter->axisItems();
ChartTitle *title = m_presenter->titleElement();